@@ -1,6 +1,7 @@
 #! /usr/bin/env bash
 
 alias @ai=bluer_ai
+alias @i=bluer_ai
 
 alias @assets=bluer_objects_assets
 
@@ -33,6 +34,8 @@ alias @mysql=abcli_mysql
 
 alias @objects=bluer_objects
 
+alias @pdf=bluer_objects_pdf
+
 alias @random=bluer_ai_string_random
 
 alias @select=bluer_ai_select
