@@ -41,11 +41,13 @@ def build_me() -> bool:
                 "assets",
                 "clone",
                 "download",
+                "file",
                 "gif",
                 "host",
                 "ls",
                 "metadata",
                 "mlflow",
+                "pdf",
                 "upload",
             ]
         ]
