@@ -5,11 +5,8 @@ from bluer_options.terminal import show_usage, xtra
 from bluer_objects.storage.policies import DownloadPolicy
 
 
-def help_download(
-    tokens: List[str],
-    mono: bool,
-) -> str:
-    options = "".join(
+def options(mono: bool) -> str:
+    return "".join(
         [
             "filename=<filename>",
             xtra(
@@ -21,12 +18,17 @@ def help_download(
         ]
     )
 
+
+def help_download(
+    tokens: List[str],
+    mono: bool,
+) -> str:
     open_options = "open,QGIS"
 
     return show_usage(
         [
             "@download",
-            f"[{options}]",
+            f"[{options(mono=mono)}]",
             "[.|<object-name>]",
             f"[{open_options}]",
         ],
