@@ -3,21 +3,23 @@ from typing import List
 from bluer_options.terminal import show_usage, xtra
 
 
-def help_upload(
-    tokens: List[str],
-    mono: bool,
-) -> str:
-    options = "".join(
+def options(mono: bool) -> str:
+    return "".join(
         [
             "filename=<filename>",
             xtra(",public,zip", mono=mono),
         ]
     )
 
+
+def help_upload(
+    tokens: List[str],
+    mono: bool,
+) -> str:
     return show_usage(
         [
             "@upload",
-            f"[{options}]",
+            f"[{options(mono=mono)}]",
             "[.|<object-name>]",
         ],
         "upload <object-name>.",
